﻿'''**************************************************************************
' Project  : AvionicsInstrumentControlDemo                                  
' File     : TurnCoordinatorInstrumentControl.cs                            
' Version  : 1                                                              
' Language : C#                                                             
' Summary  : The turn coordinator instrument control                        
' Creation : 15/06/2008                                                     
' Autor    : Guillaume CHOUTEAU                                             
' History  :                                                                
'''**************************************************************************

Imports System.ComponentModel
Imports System.Windows.Forms
Imports System.Collections
Imports System.Drawing
Imports System.Text
Imports System.Data

Namespace AvionicsInstrumentControlDemo
    Public Class TurnCoordinatorInstrumentControl
        Inherits InstrumentControl

#Region "Fields"

        ' Parameters
        Private TurnRate As Single
        Private TurnQuality As Single

        ' Images
        Private bmpCadran As New Bitmap(My.Resources.TurnCoordinator_Background)
        Private bmpBall As New Bitmap(My.Resources.TurnCoordinatorBall)
        Private bmpAircraft As New Bitmap(My.Resources.TurnCoordinatorAircraft)
        Private bmpMarks As New Bitmap(My.Resources.TurnCoordinatorMarks)

#End Region

#Region "Contructor"

        ''' <summary>
        ''' Required designer variable.
        ''' </summary>
        Private components As System.ComponentModel.Container = Nothing

        Public Sub New()
            ' Double bufferisation
            SetStyle(ControlStyles.DoubleBuffer Or ControlStyles.UserPaint Or ControlStyles.AllPaintingInWmPaint, True)
        End Sub

#End Region

#Region "Component Designer generated code"
        ''' <summary>
        ''' Required method for Designer support - do not modify 
        ''' the contents of this method with the code editor.
        ''' </summary>
        Private Overloads Sub InitializeComponent()
            components = New System.ComponentModel.Container()
        End Sub
#End Region

#Region "Paint"

        Protected Overrides Sub OnPaint(ByVal pe As PaintEventArgs)
            ' Calling the base class OnPaint
            MyBase.OnPaint(pe)

            ' Pre Display computings
            Dim ptRotationAircraft As New Point(150, 150)
            Dim ptImgAircraft As New Point(57, 114)
            Dim ptRotationBall As New Point(150, -155)
            Dim ptImgBall As New Point(136, 216)
            Dim ptMarks As New Point(134, 216)

            bmpCadran.MakeTransparent(Color.Yellow)
            bmpBall.MakeTransparent(Color.Yellow)
            bmpAircraft.MakeTransparent(Color.Yellow)
            bmpMarks.MakeTransparent(Color.Yellow)

            Dim alphaAircraft As Double = InterpolPhyToAngle(TurnRate, -6, 6, -30, 30)
            Dim alphaBall As Double = InterpolPhyToAngle(TurnQuality, -10, 10, -11, 11)

            'INSTANT VB NOTE: The variable scale was renamed since Visual Basic does not handle local variables named the same as class members well:
            Dim scale_Renamed As Single = CSng(Me.Width) / bmpCadran.Width

            ' diplay mask
            Dim maskPen As New Pen(Me.BackColor, 30 * scale_Renamed)
            pe.Graphics.DrawRectangle(maskPen, 0, 0, bmpCadran.Width * scale_Renamed, bmpCadran.Height * scale_Renamed)

            ' display cadran
            pe.Graphics.DrawImage(bmpCadran, 0, 0, CSng(bmpCadran.Width * scale_Renamed), CSng(bmpCadran.Height * scale_Renamed))

            ' display Ball
            RotateImage(pe, bmpBall, alphaBall, ptImgBall, ptRotationBall, scale_Renamed)

            ' display Aircraft
            RotateImage(pe, bmpAircraft, alphaAircraft, ptImgAircraft, ptRotationAircraft, scale_Renamed)

            ' display Marks
            pe.Graphics.DrawImage(bmpMarks, CInt(Fix(ptMarks.X * scale_Renamed)), CInt(Fix(ptMarks.Y * scale_Renamed)), bmpMarks.Width * scale_Renamed, bmpMarks.Height * scale_Renamed)

        End Sub

#End Region

#Region "Methods"

        ''' <summary>
        ''' Define the physical value to be displayed on the indicator
        ''' </summary>
        ''' <param name="aircraftTurnRate">The aircraft turn rate in �deg per minutes</param>
        ''' <param name="aircraftTurnQuality">The aircraft turn quality</param>
        Public Sub SetTurnCoordinatorParameters(ByVal aircraftTurnRate As Single, ByVal aircraftTurnQuality As Single)
            TurnRate = aircraftTurnRate
            TurnQuality = aircraftTurnQuality

            Me.Refresh()
        End Sub

#End Region
    End Class
End Namespace
